<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>Duplikuj</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>Rozszerz</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>Tylko na %1</translation>
    </message>
</context>
</TS>